/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.facebook.litho.intellij.toolwindows;

import com.facebook.litho.specmodels.model.SpecModel;
import com.intellij.ide.structureView.StructureViewModel;
import com.intellij.ide.structureView.StructureViewModelBase;
import com.intellij.ide.structureView.StructureViewTreeElement;
import com.intellij.psi.PsiFile;

/** Structure view containing both leafs and branches. */
class ComponentTreeModel extends StructureViewModelBase
    implements StructureViewModel.ElementInfoProvider {

  static StructureViewModel create(PsiFile selectedFile, SpecModel model) {
    final StructureViewTreeElement viewTreeElement = SpecTreeElementFactory.createTree(model);
    return new ComponentTreeModel(selectedFile, viewTreeElement);
  }

  public ComponentTreeModel(PsiFile psiFile, StructureViewTreeElement model) {
    super(psiFile, model);
  }

  @Override
  public boolean isAlwaysShowsPlus(StructureViewTreeElement element) {
    return false;
  }

  @Override
  public boolean isAlwaysLeaf(StructureViewTreeElement element) {
    return false;
  }
}
